@@ -12,7 +12,7 @@ soil.texture<-function(soiltexture=NULL,main="",at=seq(0.1,0.9,by=0.1),
 
  par(xpd=TRUE)
  plot(0.5,type="n",axes=FALSE,xlim=c(0,1),ylim=c(0,1),main=NA,xlab=NA, ylab=NA)
- triax.frame(main=main,at=at,axis.labels=axis.labels,tick.labels=tick.labels,
+ triax.plot(x=NULL,main=main,at=at,axis.labels=axis.labels,tick.labels=tick.labels,
   col.axis=col.axis,show.grid=show.grid,col.grid=col.grid,lty.grid=lty.grid)
  arrows(0.12,0.41,0.22,0.57,length=0.15)
  arrows(0.78,0.57,0.88,0.41,length=0.15)
